[Pcsclite-cvs-commit] r5276 - in /website: disabled.css disabled.ini matrix.css matrix.py supported.ini unsupported.ini

rousseau at users.alioth.debian.org rousseau at users.alioth.debian.org
Sat Oct 2 11:17:56 UTC 2010


Author: rousseau
Date: Sat Oct  2 11:17:53 2010
New Revision: 5276

URL: http://svn.debian.org/wsvn/pcsclite/?sc=1&rev=5276
Log:
Add a "disabled" category

Added:
    website/disabled.css
    website/disabled.ini
Modified:
    website/matrix.css
    website/matrix.py
    website/supported.ini
    website/unsupported.ini

Added: website/disabled.css
URL: http://svn.debian.org/wsvn/pcsclite/website/disabled.css?rev=5276&op=file
==============================================================================
--- website/disabled.css (added)
+++ website/disabled.css Sat Oct  2 11:17:53 2010
@@ -1,0 +1,5 @@
+body{background:#555;color:#fff}
+h1{background:#888;}
+h2{background:#aaa;}
+h3{background:#ccc;}
+span.features{background:yellow;color:black}

Added: website/disabled.ini
URL: http://svn.debian.org/wsvn/pcsclite/website/disabled.ini?rev=5276&op=file
==============================================================================
--- website/disabled.ini (added)
+++ website/disabled.ini Sat Oct  2 11:17:53 2010
@@ -1,0 +1,48 @@
+; **************************************************************************
+;                    Broken and disabled by the driver
+; **************************************************************************
+
+[BludriveII.txt]
+image = BludriveII_CCID.png
+url = http://shop.blutronics.com/ViewProdotti.asp?IdMarca=3&Id=751
+note = The USB descriptor is bogus and the patch in get_ccid_usb_interface() does not work with libusb-1.0 
+[HP_kus-0133.txt]
+note = SetParameters fails with a card of ATR 3B 16 96 41 73 74 72 69 64. The smart card reader part is from SCM.
+[iDream.txt]
+image = THRC2002-2.png
+url = http://www.idream.be/consulter.php?pid=50&tab=2
+note = also known as ID-SMID01  and maybe other commercial names
+ PPS fails with a Cryptoflex card
+ Powerup fails with a Setcos card
+[jNet_jToken_s1.txt]
+[Oberthur-CosmoCard1.txt]
+note = The reader responds with bResponseType not defined in ICCD v1.0 specification. See http://archives.neohapsis.com/archives/dev/muscle/2009-q4/0059.html
+[Oz776S.txt]
+note = This reader is common as an internal reader in laptops like the Dell D420 or D820.
+ The ATR may be corrupted by a 90 00 at the end
+ The reader is bogus and does not accept PPS
+ The USB descriptor is bogus and the patch in get_ccid_usb_interface() does not work with libusb-1.0 
+[Oz776_7772.txt]
+note = This reader is common as an internal reader in laptops.
+ The reader is bogus and does not accept PPS
+ The USB descriptor is bogus and the patch in get_ccid_usb_interface() does not work with libusb-1.0 
+[ReinerSCT.txt]
+image = reiner-pinpad.png
+url = http://www.reiner-sct.com/content/view/4/16/
+note = Time requests are not managed and the driver may time out without any response from the reader.  This is not a problem unless you use a time-consuming APDU like RSA key generation.
+ Reiner provides a free software driver for this reader: http://support.reiner-sct.de/
+ The USB descriptor is bogus and the patch in get_ccid_usb_interface() does not work with libusb-1.0 
+[SCL010.txt]
+image = SCL010.png
+url = http://www.scmmicro.com/products-services/smart-card-readers-terminals/contactless-dual-interface-readers/scl010.html
+features = contactless
+note = The contactless interface is not supported.
+[SCL01x.txt]
+image = SCL010.png
+url = http://www.scmmicro.com/products-services/smart-card-readers-terminals/contactless-dual-interface-readers/scl010.html
+features = contactless
+note = The contactless interface is not supported.
+[Smart_SBV280.txt]
+url = http://www2.smarttech.com/st/en-US/Products/SMART+Boards/Front+projection/V280/default.htm
+image = SBV280.png
+note = Removed on manufacturer request. They use libusb directly in their own driver.

Modified: website/matrix.css
URL: http://svn.debian.org/wsvn/pcsclite/website/matrix.css?rev=5276&op=diff
==============================================================================
--- website/matrix.css (original)
+++ website/matrix.css Sat Oct  2 11:17:53 2010
@@ -4,3 +4,5 @@
 tr.shouldwork_odd, td.shouldwork_odd {background-color:#a0eeee;}
 tr.unsupported, td.unsupported {background-color:#ffa0a0;}
 tr.unsupported_odd, td.unsupported_odd {background-color:#eea0a0;}
+tr.disabled, td.disabled {background-color:#a0a0a0;}
+tr.disabled_odd, td.disabled_odd {background-color:#909090;}

Modified: website/matrix.py
URL: http://svn.debian.org/wsvn/pcsclite/website/matrix.py?rev=5276&op=diff
==============================================================================
--- website/supported.ini (original)
+++ website/supported.ini Sat Oct  2 11:17:53 2010
@@ -109,7 +109,6 @@
 features = contactless
 url = http://support.gemalto.com/index.php?id=408
 [HPUSBSmartCardReader.txt]
-[jNet_jToken_s1.txt]
 [KAAN_Advanced.txt]
 image = Kobil_Advanced.png
 url = http://www.kobil.com/index.php?id=68&type=7&L=0

Modified: website/unsupported.ini
URL: http://svn.debian.org/wsvn/pcsclite/website/unsupported.ini?rev=5276&op=diff
==============================================================================
--- website/unsupported.ini (original)
+++ website/unsupported.ini Sat Oct  2 11:17:53 2010
@@ -19,10 +19,6 @@
 note = The token does not work after a warm reset. See http://www.opensc-project.org/pipermail/opensc-devel/2009-April/012128.html
 [Athena_IDProtect_Key.txt]
 note = PPS to set the card in T=1 fails. See http://www.opensc-project.org/pipermail/opensc-user/2010-May/004023.html
-[BludriveII.txt]
-image = BludriveII_CCID.png
-url = http://shop.blutronics.com/ViewProdotti.asp?IdMarca=3&Id=751
-note = The USB descriptor is bogus and the patch in get_ccid_usb_interface() does not work with libusb-1.0 
 [Broadcom_5880v2.txt]
 note = Found in Dell E6400 laptop
  The reader reports "Hardware error" to GetSlotStatus when no card is present.
@@ -38,14 +34,6 @@
  <- 000000 80 00 00 00 00 00 07 40 FE 00 
  commands.c:1316:CCID_Receive Card absent or mute
  And time extension requests are not forwarded back to the host.
-[HP_kus-0133.txt]
-note = SetParameters fails with a card of ATR 3B 16 96 41 73 74 72 69 64. The smart card reader part is from SCM.
-[iDream.txt]
-image = THRC2002-2.png
-url = http://www.idream.be/consulter.php?pid=50&tab=2
-note = also known as ID-SMID01  and maybe other commercial names
- PPS fails with a Cryptoflex card
- Powerup fails with a Setcos card
 [LTC31.txt]
 image = LTC31.png
 url = "http://www.c3po.es/ltc31.html
@@ -62,15 +50,6 @@
 note = Time requests are not managed correctly and make the firmware fail.  This is not a problem unless you use a time-consuming APDU like RSA key generation.
 
  A new firmware will correct the bug.
-[Oberthur-CosmoCard1.txt]
-note = the reader responds with bResponseType not defined in ICCD v1.0 specification. See http://archives.neohapsis.com/archives/dev/muscle/2009-q4/0059.html
-[Oz776S.txt]
-note = This reader is common as an internal reader in laptops like the Dell D420 or D820.
- The ATR may be corrupted by a 90 00 at the end
- The reader is bogus and does not accept PPS
-[Oz776_7772.txt]
-note = This reader is common as an internal reader in laptops.
- The reader is bogus and does not accept PPS
 [Precise_200_MC.txt]
 image = Precise200MC.png
 url = http://precisebiometrics.com/?id=2718&cid=2722
@@ -79,22 +58,3 @@
 image = Precise250MC.png
 url = http://precisebiometrics.com/?id=2718&cid=2723
 note = Must be firmware version 50.00 or above: time extension requests are not sent back to the host in earlier versions of the firmware. The reader can't talk to card with TA1=96. See http://archives.neohapsis.com/archives/dev/muscle/2010-q3/0197.html
-[ReinerSCT.txt]
-image = reiner-pinpad.png
-url = http://www.reiner-sct.com/content/view/4/16/
-note = Time requests are not managed and the driver may time out without any response from the reader.  This is not a problem unless you use a time-consuming APDU like RSA key generation.
- Reiner provides a free software driver for this reader: http://support.reiner-sct.de/
-[Smart_SBV280.txt]
-url = http://www2.smarttech.com/st/en-US/Products/SMART+Boards/Front+projection/V280/default.htm
-image = SBV280.png
-note = Removed on manufacturer request. They use libusb directly.
-[SCL010.txt]
-image = SCL010.png
-url = http://www.scmmicro.com/products-services/smart-card-readers-terminals/contactless-dual-interface-readers/scl010.html
-features = contactless
-note = The contactless interface is not supported.
-[SCL01x.txt]
-image = SCL010.png
-url = http://www.scmmicro.com/products-services/smart-card-readers-terminals/contactless-dual-interface-readers/scl010.html
-features = contactless
-note = The contactless interface is not supported.




More information about the Pcsclite-cvs-commit mailing list
--- website/matrix.py (original)
+++ website/matrix.py Sat Oct  2 11:17:53 2010
@@ -166,7 +166,12 @@
     for line in supported_readers:
         # skip comments
         if line.startswith("#"):
-            continue
+            # but get commented readers
+            if line.startswith("#0"):
+                # remove the leading #
+                line = line[1:]
+            else:
+                continue
 
         # remove newline
         line = line.rstrip()
@@ -410,6 +415,7 @@
     <td class="supported">supported</td>
     <td class="shouldwork">should work</td>
     <td class="unsupported">unsupported</td>
+    <td class="disabled">disabled</td>
     </tr></table></li>
     <li><a class="FlattrButton" style="display:none;"
             href="http://pcsclite.alioth.debian.org/ccid.html"></a></li>
@@ -480,8 +486,9 @@
         for r in readers.keys():
             index.append([readers[r].get(f, ""), r])
         if f == 'section':
             # hack to sort in the order supported, shouldwork, unsupported
             index = [(s.replace('supported', 'asupported'), r) for s, r in index]
+            index = [(s.replace('disabled', 'zdisabled'), r) for s, r in index]
         if f in ['dwDefaultClock', 'dwMaximumClock', 'dwDataRate',
                 'dwMaxDataRate', 'dwMaxIFSD', 'dwMaxCCIDMessageLength']:
             # convert from text to decimal
@@ -509,11 +516,13 @@
     supported_readers = parse_ini(path, "supported")
     shouldwork_readers = parse_ini(path, "shouldwork")
     unsupported_readers = parse_ini(path, "unsupported")
+    disabled_readers = parse_ini(path, "disabled")
 
     # all_readers contain the union of the 3 lists
     all_readers = dict(supported_readers)
     all_readers.update(shouldwork_readers)
     all_readers.update(unsupported_readers)
+    all_readers.update(disabled_readers)
 
     check_list(path, all_readers.keys())
     check_supported(path, all_readers)
@@ -522,9 +531,11 @@
     get_driver_version(supported_readers)
     get_driver_version(shouldwork_readers)
     get_driver_version(unsupported_readers)
+    get_driver_version(disabled_readers)
 
     generate_page("supported", "Supported CCID readers/ICCD tokens", "If you are a reader manufacturer and your reader is not listed here then contact me at ludovic.rousseau at free.fr", supported_readers)
     generate_page("shouldwork", "Should work but untested by me", "The CCID readers and ICCD tokens listed bellow should work with the driver but have not be validated by me. I would like to get these readers to perform test and validation and move them in the supported list above. If you are one of the manufacturers, please, contact me at ludovic.rousseau at free.fr.", shouldwork_readers)
     generate_page("unsupported", "Unsupported or partly supported CCID readers", "These readers have problems or serious limitations.", unsupported_readers)
+    generate_page("disabled", "Disabled CCID readers", "These readers are not even recognized by the driver because they are too bogus or because they are supported by another driver.", disabled_readers)
 
     generate_tables(all_readers)
@@ -480,8 +486,9 @@
             index.append([readers[r].get(f, ""), r])
         if f == 'section':
-            # hack to sort in the order supported, shouldwork, unsupported
+            # hack to sort in the order supported, shouldwork, unsupported, disabled
             index = [(s.replace('supported', 'asupported'), r) for s, r in index]

Modified: website/supported.ini
URL: http://svn.debian.org/wsvn/pcsclite/website/supported.ini?rev=5276&op=diff
==============================================================================